================================
BYU Hydroinformatics Laboratory
================================

About us
~~~~~~~~
  .. image:: https://brightspotcdn.byu.edu/dims4/default/3467dcb/2147483647/strip/true/crop/3312x2484+0+268/resize/400x300!/quality/90/?url=https%3A%2F%2Fbrigham-young-brightspot.s3.amazonaws.com%2F95%2Fce%2F548e128d4a95bb0588d4a923f03c%2Fgroup-photo-true.jpg
     :align: center
     :height: 800px
     :width: 1000 px
     :scale: 50 %

  The Hydroinformatics laboratory at BYU focuses in delivering different software product and services for water modeling. Some of the most important
  work involves: `Global streamflow Forecast Services API <https://worldwater.byu.edu/global-streamflow-forecasts>`__, creation of the `Tethys Platform <https://www.tethysplatform.org/>`__,
  `Hydroserver_lite <http://128.187.106.131/Historical_Data_template.php>`__, and much more. The most recent publication and work can be found in official `BYU_Hydroinformatics <https://worldwater.byu.edu/>`__ website
